@@ -1,5 +1,5 @@
 from typing import Final
-from volsite_postgres_common.db.CFn import CFn
+from volsite_postgres_common.db import CFn
 from volsite_postgres_common.fn.insert import insert_function
 
 ID_PREFIX: Final = 'i'
